﻿using System.Windows.Forms;

using MindFusion.Diagramming;


namespace ParamShapes
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			diagram.NodeEffects.Add(new GlassEffect());

			// a rounded rectangle shape, with an arc at each corner
			string roundRect = @"
				r = Min(Width / 2, radius.X);
				MoveTo(r, 0);
				LineTo(Width - r, 0);
				ArcTo(Width, r, false, false, r, r);
				LineTo(Width, Height - r);
				ArcTo(Width - r, Height, false, false, r, r);
				LineTo(r, Height);
				ArcTo(0, Height - r, false, false, r, r);
				LineTo(0, r);
				ArcTo(r, 0, false, false, r, r);
			 ";

			var myRect = new Shape(roundRect, "MyRect");

			// add a control point for the 'radius' parameter
			myRect.ControlPoints.Add(new ShapeControlPoint(
				"radius", 5, 1, 15, UnitType.Fixed, 0, 0, 0, UnitType.Fixed));

			// an anchor shape, with two arcs outlining each anchor arm
			string anchor = @"
				r = Width / 3;
				y1 = p1.Y * Height / 100;
				y2 = p2.Y * Height / 100;
				MoveTo(Width / 2, Height);
				MoveTo(Width / 2 + 3, Height - 5);
				ArcTo(Width, y2, false, true, r, r);
				ArcTo(Width / 2 + 3, Height - 10, false, false, r, r);
				LineTo(Width / 2 + 3, 0);
				LineTo(Width / 2 - 3, 0);
				LineTo(Width / 2 - 3, Height - 10);
				ArcTo(0, y1, false, false, r, r);
				ArcTo(Width / 2 - 3, Height - 5, false, true, r, r);
				LineTo(Width / 2, Height);
			 ";

			var myAnchor = new Shape(anchor, "MyAnchor");

			// add control points at the tips of anchor arms
			myAnchor.ControlPoints.Add(new ShapeControlPoint(
				"p1", 0, 0, 0, UnitType.Percentage, 55, 50, 80, UnitType.Percentage));
			myAnchor.ControlPoints.Add(new ShapeControlPoint(
				"p2", 100, 100, 100, UnitType.Percentage, 55, 50, 80, UnitType.Percentage));

			// create several sample nodes
			diagram.Factory.CreateShapeNode(10, 10, 40, 40, myRect);
			diagram.Factory.CreateShapeNode(60, 10, 40, 40, myRect);
			diagram.Factory.CreateShapeNode(10, 60, 40, 40, myAnchor);
			diagram.Factory.CreateShapeNode(60, 60, 40, 40, myAnchor);
		}
	}
}